==> owlapi-api-3.4.10-sources.jar: org/semanticweb/owlapi/reasoner/ReasonerInternalException.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.semanticweb.owlapi.reasoner;

/** Specifies that a some internal error occurred during reasoning. Each reasoner
 * implementation will specify the cause of the error in the message. <br>
 * This exception is only thrown when an internal error (due to errors in the
 * reasoner code) has occurred and the reasoner cannot recover silently from the
 * error. If the reasoner can recover silently this exception will not be
 * thrown. <br>
 * Clients should dispose of the reasoner when an internal reasoner exception is
 * thrown because the error is unrecoverable and the internal state of the
 * reasoner may be corrupt.
 * 
 * @author Matthew Horridge, The University of Manchester, Bio-Health
 *         Informatics Group, Date: 05-Jul-2010 */
public class ReasonerInternalException extends OWLReasonerRuntimeException {
    private static final long serialVersionUID = 30406L;

    /** @param cause
     *            error cause */
    public ReasonerInternalException(Throwable cause) {
        super(cause);
    }

    /** @param message
     *            error message */
    public ReasonerInternalException(String message) {
        super(message);
    }

    /** @param message
     *            error message
     * @param cause
     *            error cause */
    public ReasonerInternalException(String message, Throwable cause) {
        super(message, cause);
    }
}

==> owlapi-api-3.5.0-sources.jar: org/semanticweb/owlapi/reasoner/ReasonerInternalException.java <==
/*
 * This file is part of the OWL API.
 *
 * The contents of this file are subject to the LGPL License, Version 3.0.
 *
 * Copyright (C) 2011, The University of Manchester
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0
 * in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 *
 * Copyright 2011, University of Manchester
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.semanticweb.owlapi.reasoner;

/**
 * Specifies that a some internal error occurred during reasoning. Each reasoner
 * implementation will specify the cause of the error in the message. <br>
 * This exception is only thrown when an internal error (due to errors in the
 * reasoner code) has occurred and the reasoner cannot recover silently from the
 * error. If the reasoner can recover silently this exception will not be
 * thrown. <br>
 * Clients should dispose of the reasoner when an internal reasoner exception is
 * thrown because the error is unrecoverable and the internal state of the
 * reasoner may be corrupt.
 * 
 * @author Matthew Horridge, The University of Manchester, Bio-Health
 *         Informatics Group, Date: 05-Jul-2010
 */
public class ReasonerInternalException extends OWLReasonerRuntimeException {

    private static final long serialVersionUID = 30406L;

    /**
     * @param cause
     *        error cause
     */
    public ReasonerInternalException(Throwable cause) {
        super(cause);
    }

    /**
     * @param message
     *        error message
     */
    public ReasonerInternalException(String message) {
        super(message);
    }

    /**
     * @param message
     *        error message
     * @param cause
     *        error cause
     */
    public ReasonerInternalException(String message, Throwable cause) {
        super(message, cause);
    }
}
